"use client";
import React, { useState, useEffect, useCallback } from 'react';
import Table from './Table';
import Sidebar from '@/components/dashboard/Sidebar';
import axios from '@/services/APIservices';


const Page = () => {
  // State Management
  const [userData, setUserData] = useState(null);
  const [inquiryData, setInquiryData] = useState(null);
  const [profilePhoto, setProfilePhoto] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState(null);

  // Fetch User Data from Local Storage
  useEffect(() => {
    const storedUserData = localStorage.getItem('userData');
    console.log('Stored User Data:', storedUserData);
    if (storedUserData) {
      setUserData(JSON.parse(storedUserData));
    }
  }, []);

  // Fetch Inquiry Data with Polling
  const fetchInquiryData = useCallback(async (userId) => {
    if (!userId) return;
    console.log('Fetching data for userId:', userId);
    try {
      const response = await axios.get(`/api/user-inquiry/${userId}`);
      console.log('Response:', response);
      setInquiryData(response.data);
      
      // Extract profile photo from the first inquiry if available
      if (response.data?.allInquiryData?.length > 0) {
        const firstInquiry = response.data.allInquiryData[0];
        setProfilePhoto(firstInquiry.profile_photo || null);
      }
      
      setError(null);
    } catch (err) {
      console.error('Error fetching inquiry data:', err);
      if (err.response) {
        setError(`Error: ${err.response.data.message || 'Unknown error'}`);
      } else {
        setError('Failed to load inquiry data');
      }
    }
  }, []);

  // Real-time Polling Setup
  useEffect(() => {
    const userId = userData?.user_id;
    if (userId) {
      fetchInquiryData(userId);
      const pollInterval = setInterval(() => {
        fetchInquiryData(userId);
      }, 5000);
      return () => clearInterval(pollInterval);
    }
  }, [userData, fetchInquiryData]);

  // Derived Values
  const userId = userData?.user_id || null;

  return (
    <div className='bg-[#ededed] min-h-screen flex flex-col justify-center px-4 md:px-16'>
      <div className='flex flex-col md:flex-row gap-8 md:gap-16'>
        {/* Sidebar with profile photo */}
        <Sidebar 
          path="/my-enquiry" 
          userId={userId} 
          userImage={profilePhoto}
        />
        
        {/* Main Content */}
        <div className='flex-1'>
          {/* Loading State */}
          {isLoading && !inquiryData && (
            <div className='text-center text-gray-600 py-4'>
              Loading inquiries...
            </div>
          )}
          
          {/* Error State */}
          {error && (
            <div className='bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative'>
              {error}
            </div>
          )}
          
          {/* Table with Inquiry Data */}
          <Table
            columns={columns}
            data={inquiryData}
          />
        </div>
      </div>
    </div>
  );
};

export default Page; 